@@ -14,14 +14,9 @@
 #' @rdname Evaporative
 #' @aliases Evaporative print.Evaporative summary.Evaporative
 #' plot.Evaporative
-#' @examples \dontrun{
+#' @examples {
 #' ef1 <- ef_evap(ef = "erhotc",v = "PC", cc = "<=1400", dt = "0_15", ca = "no")
-#' class(ef1)
-#' dfe <- emis_evap(rep(50,3),"PC","<=1400","G", 1:3,
-#'                      10,4,2,1,
-#'                      ef1*1:3, ef1*1:3, ef1*1:3, ef1*1:3,
-#'                      ef1*1:3, ef1*1:3, ef1*1:3, ef1*1:3,
-#'                      ef1*1:3, ef1*1:3, ef1*1:3, ef1*1:3)
+#' ef1
 #' }
 #' @export
 Evaporative <- function(x, ...) {
@@ -38,7 +33,7 @@ if ( is.numeric(ev) ) {
 #' @export
 print.Evaporative <- function(x, ...) {
   cat("Result for Evaporative")
-  print(unclass(x),  ...)
+  print(x,  ...)
 }
 
 #' @rdname Evaporative
