@@ -14,71 +14,62 @@
 #' @param type type of geometry: "lines" or "points".
 #' @importFrom sf st_sf st_dimension st_transform st_length st_cast st_intersection
 #' @importFrom data.table data.table .SD
+#' @importFrom sp CRS
 #' @export
 #' @note When spobj is a 'Spatial' object (class of sp), they are converted
 #'  into 'sf'. Also, The aggregation of data ise done with data.table functions.
-#' @examples \dontrun{
+#' @examples {
 #' data(net)
-#' data(pc_profile)
-#' data(fe2015)
-#' data(fkm)
-#' PC_G <- c(33491,22340,24818,31808,46458,28574,24856,28972,37818,49050,87923,
-#'           133833,138441,142682,171029,151048,115228,98664,126444,101027,
-#'           84771,55864,36306,21079,20138,17439, 7854,2215,656,1262,476,512,
-#'           1181, 4991, 3711, 5653, 7039, 5839, 4257,3824, 3068)
-#' veh <- data.frame(PC_G = PC_G)
-#' pc1 <- my_age(x = net$ldv, y = PC_G, name = "PC")
-#' pcw <- temp_fact(net$ldv+net$hdv, pc_profile)
-#' speed <- netspeed(pcw, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1)
-#' pckm <- fkm[[1]](1:24); pckma <- cumsum(pckm)
-#' cod1 <- emis_det(po = "CO", cc = 1000, eu = "III", km = pckma[1:11])
-#' cod2 <- emis_det(po = "CO", cc = 1000, eu = "I", km = pckma[12:24])
-#' #vehicles newer than pre-euro
-#' co1 <- fe2015[fe2015$Pollutant=="CO", ] #24 obs!!!
-#' cod <- c(co1$PC_G[1:24]*c(cod1,cod2),co1$PC_G[25:nrow(co1)])
-#' lef <- ef_ldv_scaled(co1, cod, v = "PC", t = "4S", cc = "<=1400",
-#'                      f = "G",p = "CO", eu=co1$Euro_LDV)
-#' E_CO <- emis(veh = pc1,lkm = net$lkm, ef = lef, speed = speed, agemax = 41,
-#'              profile = pc_profile, hour = 24, day = 7, array = TRUE)
-#' # arguments required: arra, pollutant ad by
-#' E_CO_STREETS <- emis_post(arra = E_CO, pollutant = "CO", by = "streets_wide")
-#' net@data <- cbind(net@data, E_CO_STREETS)
-#' head(net@data)
-#' g <- make_grid(net, 1/102.47/2, 1/102.47/2) #500m in degrees
-#'
-#' net@data <- net@data[,- c(1:9)]
+#' g <- make_grid(net, 1/102.47/2) #500m in degrees
 #' names(net)
-#' E_CO_g <- emis_grid(spobj = net, g = g, sr= 31983)
-#' head(E_CO_g) #class sf
-#' E_CO_g$V138 <- as.numeric(E_CO_g$V138)
-#' E_CO_g <- as(E_CO_g, "Spatial")
-#' spplot(E_CO_g, "V138", scales=list(draw=T),cuts=8,
-#' colorkey = list(space = "bottom", height = 1),
-#' col.regions = rev(bpy.colors(9)),
-#' sp.layout = list("sp.lines", net, pch = 16, cex = 2, col = "black"))
+#' netsf <- sf::st_as_sf(net)
+#' netg <- emis_grid(spobj = netsf[, c("ldv", "hdv")], g = g, sr= 31983)
+#' plot(netg["ldv"], axes = TRUE)
+#' plot(netg["hdv"], axes = TRUE)
 #' }
 emis_grid <- function(spobj, g, sr, type = "lines"){
   net <- sf::st_as_sf(spobj)
   net$id <- NULL
+  netdata <- sf::st_set_geometry(net, NULL)
+  for(i in 1:length(netdata)){
+netdata[, i] <- as.numeric(netdata[, i])
+  }
+  net <- sf::st_sf(netdata, geometry = net$geometry)
   g <- sf::st_as_sf(g)
 
   if(!missing(sr)){
+    if(class(sr)[1] == "character"){
+      sr <- as.numeric(substr(sp::CRS(sr), 12, nchar(sr)))
+    }
     message("Transforming spatial objects to 'sr' ")
   net <- sf::st_transform(net, sr)
   g <- sf::st_transform(g, sr)
   }
 
   if (type == "lines" ) {
+    netdf <- sf::st_set_geometry(net, NULL)
+    snetdf <- sum(netdf, na.rm = TRUE)
+
+    cat(paste0("Sum of street emissions ", round(snetdf, 2), "\n"))
+
     ncolnet <- ncol(sf::st_set_geometry(net, NULL))
+    # Filtrando solo columnas numericas
+    net <- net[, grep(pattern = TRUE, x = sapply(net, is.numeric))]
     namesnet <- names(sf::st_set_geometry(net, NULL))
     net$LKM <- sf::st_length(sf::st_cast(net[sf::st_dimension(net) == 1,]))
     netg <- suppressWarnings(st_intersection(net, g))
-    netg$LKM2 <- sf::st_length(sf::st_cast(netg[sf::st_dimension(netg) == 1,]))
+    netg$LKM2 <- sf::st_length(netg)
     xgg <- data.table::data.table(netg)
     xgg[, 1:ncolnet] <- xgg[, 1:ncolnet] * as.numeric(xgg$LKM2/xgg$LKM)
+    xgg[is.na(xgg)] <- 0 # prevent 1+ NA = NA
     dfm <- xgg[, lapply(.SD, sum, na.rm=TRUE),
                by = "id",
                .SDcols = namesnet]
+    id <- dfm$id
+    dfm <- dfm*snetdf/sum(dfm, na.rm = TRUE)
+    cat(paste0("Sum of gridded emissions ",
+               round(sum(dfm, na.rm = T), 2), "\n"))
+    dfm$id <- id
     names(dfm) <- c("id", namesnet)
     gx <- data.frame(id = g$id)
     gx <- merge(gx, dfm, by="id", all.x = TRUE)
@@ -93,6 +84,7 @@ emis_grid <- function(spobj, g, sr, type = "lines"){
     xgg <- data.table::data.table(
       sf::st_set_geometry(sf::st_intersection(net, g), NULL)
       )
+    xgg[is.na(xgg)] <- 0
     dfm <- xgg[, lapply(.SD, sum, na.rm=TRUE),
                by = "id",
                .SDcols = namesnet ]
