@@ -136,7 +136,7 @@ cod2 <- emis_det(po = "CO", cc = 1000, eu = "I", km = pckma[12:24])
 #vehicles newer than pre-euro
 co1 <- fe2015[fe2015$Pollutant == "CO", ] #24 obs!!!
 cod <- c(co1$PC_G[1:24] * c(cod1, cod2), co1$PC_G[25:nrow(co1)])
-lef <- ef_ldv_scaled(co1, cod, v = "PC", cc = "<=1400",
+lef <- ef_ldv_scaled(dfcol = cod, v = "PC", cc = "<=1400",
                      f = "G",p = "CO", eu=co1$Euro_LDV)
 # lef <- c(lef,lef[length(lef)],lef[length(lef)],lef[length(lef)],
 #          lef[length(lef)],lef[length(lef)])
